Skip to contents

A sample from the Current Population Survey containing women's earnings data with motherhood status, used to demonstrate the causal variance decomposition.

Usage

data(cps_sample)

Format

An object of class tbl_df (inherits from tbl, data.frame) with 65562 rows and 32 columns.

References

Sarah Flood, Miriam King, Renae Rodgers, Steven Ruggles, J. Robert Warren and Michael Westberry. Integrated Public Use Microdata Series, Current Population Survey: Version 9.0 [dataset]. Minneapolis, MN: IPUMS, 2021. doi:10.18128/D030.V9.0

Examples

data(cps_sample)