Stacks two or more ineqx result objects into a single comparison object with a scenario column. Useful for comparing observed vs counterfactual decompositions, or multiple counterfactual scenarios.
Value
An object of class ineqx_compare containing:
- data
Long-format data.frame with a
scenariocolumn- class_type
Character: the shared class of the input objects
- scenarios
Character vector of scenario names
- ystat
Character: shared inequality measure
- ref
Numeric: shared reference period (for longitudinal)
- objects
List of original input objects